@@ -25,6 +25,7 @@ import locale
 import getopt
 import os.path
 import shutil
+import signal
 import sys
 import traceback
 import time
@@ -79,7 +80,8 @@ from picard.util import (
     pathcmp,
     partial,
     queue,
-    thread
+    thread,
+    puid_validate
     )
 from picard.webservice import XmlWebService
 
@@ -183,11 +185,14 @@ class Tagger(QtGui.QApplication):
 
         # Load plugins
         self.pluginmanager = PluginManager()
+        user_plugin_dir = os.path.join(self.userdir, "plugins")
+        if not os.path.exists(user_plugin_dir):
+            os.makedirs(user_plugin_dir)
+        self.pluginmanager.load(user_plugin_dir)
         if hasattr(sys, "frozen"):
             self.pluginmanager.load(os.path.join(os.path.dirname(sys.argv[0]), "plugins"))
         else:
             self.pluginmanager.load(os.path.join(os.path.dirname(__file__), "plugins"))
-        self.pluginmanager.load(os.path.join(self.userdir, "plugins"))
 
         self.puidmanager = PUIDManager()
 
@@ -203,12 +208,18 @@ class Tagger(QtGui.QApplication):
 
     def setup_gettext(self, localedir):
         """Setup locales, load translations, install gettext functions."""
+        if self.config.setting["ui_language"]:
+            os.environ['LANGUAGE'] = ''
+            os.environ['LANG'] = self.config.setting["ui_language"]
         if sys.platform == "win32":
             try:
                 locale.setlocale(locale.LC_ALL, os.environ["LANG"])
             except KeyError:
                 os.environ["LANG"] = locale.getdefaultlocale()[0]
-                locale.setlocale(locale.LC_ALL, "")
+                try:
+                    locale.setlocale(locale.LC_ALL, "")
+                except:
+                    pass
             except:
                 pass
         else:
@@ -284,8 +295,8 @@ class Tagger(QtGui.QApplication):
             trackid = file.metadata['musicbrainz_trackid']
             albumid = file.metadata['musicbrainz_albumid']
             self.puidmanager.add(puid, trackid)
-            if albumid:
-                if trackid:
+            if puid_validate(albumid):
+                if puid_validate(trackid):
                     self.move_file_to_album(file, albumid)
                 else:
                     self.move_file_to_track(file, albumid, trackid)
@@ -297,7 +308,7 @@ class Tagger(QtGui.QApplication):
         self.log.debug("Adding files %r", filenames)
         new_files = []
         for filename in filenames:
-            filename = os.path.normpath(filename)
+            filename = os.path.normpath(os.path.realpath(filename))
             if filename not in self.files:
                 file = open_file(filename)
                 if file:
@@ -409,11 +420,11 @@ class Tagger(QtGui.QApplication):
             file.save(self._file_saved, self.thread_pool,
                       self.tagger.config.setting)
 
-    def load_album(self, id, catalognumber=None):
+    def load_album(self, id, catalognumber=None, discid=None):
         album = self.get_album_by_id(id)
         if album:
             return album
-        album = Album(id, catalognumber=catalognumber)
+        album = Album(id, catalognumber=catalognumber, discid=discid)
         self.albums.append(album)
         self.emit(QtCore.SIGNAL("album_added"), album)
         album.load()
@@ -432,9 +443,10 @@ class Tagger(QtGui.QApplication):
     def remove_files(self, files, from_parent=True):
         """Remove files from the tagger."""
         for file in files:
-            self.analyze_queue.remove(file.filename)
-            del self.files[file.filename]
-            file.remove(from_parent)
+            if self.files.has_key(file.filename):
+                self.analyze_queue.remove(file.filename)
+                del self.files[file.filename]
+                file.remove(from_parent)
 
     def remove_album(self, album):
         """Remove the specified album."""
@@ -496,7 +508,7 @@ class Tagger(QtGui.QApplication):
                 file.metadata['musicip_puid'] = puid
                 file.lookup_puid(puid)
             else:
-                self.window.set_statusbar_message(N_("Couldn't find PUID for file %s"), file.filename)
+                self.window.set_statusbar_message(N_("Could not find PUID for file %s"), file.filename)
                 file.clear_pending()
 
     def analyze(self, objs):
@@ -592,6 +604,7 @@ def version():
 
 
 def main(localedir=None, autoupdate=True):
+    signal.signal(signal.SIGINT, signal.SIG_DFL)
     opts, args = getopt.getopt(sys.argv[1:], "hvd", ["help", "version", "debug"])
     kwargs = {}
     for opt, arg in opts:
