@@ -63,8 +63,8 @@ def register_file_action(action):
     _file_actions.register(action.__module__, action)
 
 
-def get_match_color(similarity):
-    c1 = (255, 255, 255)
+def get_match_color(similarity, basecolor):
+    c1 = (basecolor.red(), basecolor.green(), basecolor.blue())
     c2 = (223, 125, 125)
     return QtGui.QColor(
         c2[0] + (c1[0] - c2[0]) * similarity,
@@ -122,6 +122,7 @@ class MainPanel(QtGui.QSplitter):
             self.icon_dir = icontheme.lookup('folder', icontheme.ICON_SIZE_MENU)
         self.icon_file = QtGui.QIcon(":/images/file.png")
         self.icon_cd = icontheme.lookup('media-optical', icontheme.ICON_SIZE_MENU)
+        self.icon_cd_saved = icontheme.lookup('media-optical-saved', icontheme.ICON_SIZE_MENU)
         self.icon_note = QtGui.QIcon(":/images/note.png")
         self.icon_error = icontheme.lookup('dialog-error', icontheme.ICON_SIZE_MENU)
         self.icon_saved = QtGui.QIcon(":/images/track-saved.png")
@@ -194,7 +195,7 @@ class MainPanel(QtGui.QSplitter):
             text, similarity = file.column(column[1])
             item.setText(i, text)
             item.setTextColor(i, color)
-            item.setBackgroundColor(i, get_match_color(similarity))
+            item.setBackgroundColor(i, get_match_color(similarity, self.palette().base().color()))
     
     def decide_file_icon(self, file):
         if file.state == File.ERROR:
@@ -286,6 +287,11 @@ class BaseTreeView(QtGui.QTreeWidget):
         self.setDropIndicatorShown(True)
         self.setSelectionMode(QtGui.QAbstractItemView.ExtendedSelection)
 
+        self.expand_all_action = QtGui.QAction(_("&Expand all"), self)
+        self.connect(self.expand_all_action, QtCore.SIGNAL("triggered()"), self.expandAll)
+        self.collapse_all_action = QtGui.QAction(_("&Collapse all"), self)
+        self.connect(self.collapse_all_action, QtCore.SIGNAL("triggered()"), self.collapseAll)
+
         self.connect(self, QtCore.SIGNAL("doubleClicked(QModelIndex)"), self.activate_item)
 
     def set_current_release_event(self, album, checked):
@@ -340,7 +346,8 @@ class BaseTreeView(QtGui.QTreeWidget):
                 if rel.format:
                     try: name.append(RELEASE_FORMATS[rel.format])
                     except (KeyError): name.append(rel.format)
-                action = releases_menu.addAction(" / ".join(name).replace('&', '&&'))
+                event_name = " / ".join(name).replace('&', '&&')
+                action = releases_menu.addAction(event_name or _('No release event'))
                 action.setData(QtCore.QVariant(i))
                 action.setCheckable(True)
                 self.connect(action, QtCore.SIGNAL("triggered(bool)"), self._set_current_release_event)
@@ -356,6 +363,10 @@ class BaseTreeView(QtGui.QTreeWidget):
             menu.addSeparator()
             menu.addMenu(plugin_menu)
 
+        if isinstance(obj, Cluster) or isinstance(obj, Album):
+            menu.addAction(self.expand_all_action)
+            menu.addAction(self.collapse_all_action)
+
         menu.exec_(event.globalPos())
         event.accept()
 
@@ -568,7 +579,7 @@ class AlbumTreeView(BaseTreeView):
                 self.panel.unregister_object(item=file_item)
         else:
             color = self.palette().text().color()
-            bgcolor = get_match_color(1)
+            bgcolor = get_match_color(1, self.palette().base().color())
             icon = self.panel.icon_note
             
             #Add linked files (there will either be 0 or >1)
@@ -600,7 +611,7 @@ class AlbumTreeView(BaseTreeView):
             text, similarity = track.column(column[1])
             item.setText(i, text)
             item.setTextColor(i, color)
-            item.setBackgroundColor(i, get_match_color(similarity))
+            item.setBackgroundColor(i, get_match_color(similarity, self.palette().base().color()))
         if update_album:
             self.update_album(track.album, update_tracks=False)
 
@@ -622,6 +633,13 @@ class AlbumTreeView(BaseTreeView):
             self.log.debug("Item for %r not found", album)
             return
         for i, column in enumerate(self.columns):
+            font = album_item.font(i)
+            if album.is_complete():
+                icon = self.panel.icon_cd_saved
+            else:
+                icon = self.panel.icon_cd
+            album_item.setIcon(0, icon)
+            album_item.setFont(i, font)
             album_item.setText(i, album.column(column[1]))
         if update_tracks:
             oldnum = album_item.childCount() - 1
