@@ -53,7 +53,7 @@ class ReleaseEvent(object):
         for attr in self.ATTRS:
             val = getattr(self, attr)
             if val is not None:
-                m[attr] = val
+                m[attr] = val.strip()
             else:
                 try: del m[attr]
                 except KeyError: pass
@@ -95,7 +95,7 @@ class ReleaseEvent(object):
 
 class Album(DataObject, Item):
 
-    def __init__(self, id, catalognumber=None):
+    def __init__(self, id, catalognumber=None, discid=None):
         DataObject.__init__(self, id)
         self.metadata = Metadata()
         self.tracks = []
@@ -103,6 +103,7 @@ class Album(DataObject, Item):
         self._files = 0
         self._requests = 0
         self._catalognumber = catalognumber
+        self._discid = discid
         self.current_release_event = None
         self.release_events = []
         self.unmatched_files = Cluster(_("Unmatched Files"), special=2, related_album=self)
@@ -130,7 +131,7 @@ class Album(DataObject, Item):
         maxcount = max(tags.values())
         taglist = []
         for name, count in tags.items():
-            taglist.append((100 * maxcount / count, name))
+            taglist.append((100 * count / maxcount, name))
         taglist.sort(reverse=True)
         # And generate the genre metadata tag
         maxtags = self.config.setting['max_tags']
@@ -157,6 +158,11 @@ class Album(DataObject, Item):
         release_node = document.metadata[0].release[0]
         self.release_events = []
         release_to_metadata(release_node, m, config=self.config, album=self)
+        # Add empty release event
+        self.add_release_event()
+
+        if self._discid:
+            m['musicbrainz_discid'] = self._discid
 
         self.current_release_event = None
         for rel in self.release_events:
@@ -244,6 +250,18 @@ class Album(DataObject, Item):
                 # Strip leading/trailing whitespace
                 track.metadata.strip_whitespace()
 
+            # Run tagger script for release events
+            for rel in self.release_events:
+                temp_metadata = Metadata()
+                temp_metadata.copy(m)
+                rel.to_metadata(temp_metadata)
+                try:
+                    parser.eval(script, temp_metadata)
+                    rel.from_metadata(temp_metadata)
+                except:
+                    self.log.error(traceback.format_exc())
+            
+            # Run tagger script for the album itself
             try:
                 parser.eval(script, m)
             except:
@@ -266,7 +284,7 @@ class Album(DataObject, Item):
     def _finalize_loading(self, error):
         if error:
             self.metadata.clear()
-            self.metadata['album'] = _("[couldn't load album %s]") % self.id
+            self.metadata['album'] = _("[could not load album %s]") % self.id
             del self._new_metadata
             del self._new_tracks
             self.update()
@@ -274,10 +292,7 @@ class Album(DataObject, Item):
             if not self._requests:
                 for old_track, new_track in zip(self.tracks, self._new_tracks):
                     for file in old_track.linked_files:
-                        new_track.linked_files.append(file)
-                        file.parent = new_track
-                        file.metadata.copy(new_track.metadata)
-                        file.update(signal=False)
+                        file.move(new_track)
                 for track in self.tracks[len(self._new_tracks):]:
                     for file in track.linked_files:
                         file.move(self.unmatched_files)
@@ -286,6 +301,7 @@ class Album(DataObject, Item):
                 del self._new_metadata
                 del self._new_tracks
                 self.loaded = True
+                self.match_files(self.unmatched_files.files)
                 for track in self.tracks:
                     for file in track.linked_files:
                         if file.orig_metadata:
@@ -293,7 +309,6 @@ class Album(DataObject, Item):
                             break
                 self.update()
                 self.tagger.window.set_statusbar_message('Album %s loaded', self.id, timeout=3000)
-                self.match_files(self.unmatched_files.files)
 
     def load(self, force=False):
         if self._requests:
@@ -307,13 +322,24 @@ class Album(DataObject, Item):
         self._new_metadata = Metadata()
         self._new_tracks = []
         self._requests = 1
-        inc = ['tracks', 'puids', 'artist', 'release-events', 'labels']
+        require_authentication = False
+        inc = ['tracks', 'puids', 'artist', 'release-events', 'labels', 'isrcs']
         if self.config.setting['release_ars'] or self.config.setting['track_ars']:
-            inc += ['artist-rels', 'url-rels']
+            inc += ['artist-rels', 'release-rels', 'url-rels']
             if self.config.setting['track_ars']:
                 inc += ['track-level-rels']
         if self.config.setting['folksonomy_tags']:
-            inc += ['tags']
+            if self.config.setting['only_my_tags']:
+                require_authentication = True
+                inc += ['user-tags']
+            else:
+                inc += ['tags']
+        if self.config.setting['enable_ratings']:
+            require_authentication = True
+            inc += ['user-ratings']
+        if require_authentication:
+            self.tagger.xmlws.setUser(self.config.setting["username"],
+                                      self.config.setting["password"])
         self.tagger.xmlws.get_release_by_id(self.id, self._release_request_finished, inc=inc)
 
     def update(self, update_tracks=True):
@@ -321,8 +347,6 @@ class Album(DataObject, Item):
 
     def _add_file(self, track, file):
         self._files += 1
-        if file.orig_metadata:
-            self.match_release_event(file.orig_metadata)
         self.update(False)
 
     def _remove_file(self, track, file):
@@ -384,9 +408,22 @@ class Album(DataObject, Item):
     def can_refresh(self):
         return True
 
+    def get_num_matched_tracks(self):
+        num = 0
+        for track in self.tracks:
+            if track.is_linked():
+                num += 1
+        return num
+
     def get_num_unmatched_files(self):
         return len(self.unmatched_files.files)
 
+    def is_complete(self):
+        if self.tracks:
+            if self.get_num_matched_tracks() == len(self.tracks):
+                return True
+        return False
+    
     def get_num_unsaved_files(self):
         count = 0
         for track in self.tracks:
